"""
Main entry point for running the m-hass-api package as a module.

This file allows the package to be executed with:
    python -m m_hass_api
"""

from m_hass_api.hass_api_client import main

if __name__ == "__main__":
    main()
